@@ -10,7 +10,7 @@ use Hash::Merge;
 
 require Exporter;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(
@@ -196,7 +196,7 @@ Rajkumar Reddy
 
 Copyright (C) 2022 by Rajkumar Reddy. All rights reserved.
 
-Opensourced
+Open Source.
 
 
 =cut
